@@ -73,10 +73,6 @@ class ConfigHelper:
     def variables(self):
         return self.dyn_config.variables if self.dyn_config else {}
 
-    @property
-    def webapp_port(self):
-        return self.env['webapp_port']
-
     @property
     def metadata(self):
         return {
